yaml-to-docker
==============

The Wonderful fastes Dockerfile generator from a YAML File

Using
-----

Version(sh)

.. code-block:: bash

   usage: yaml-to-docker-sh <file>

.. code-block:: python

   import yaml-to-python as ytp


